@@ -35,9 +35,9 @@ if defined?(Async::HTTP)
       class WebMockClientWrapper < Client
         def initialize(
           endpoint,
-          protocol = endpoint.protocol,
-          scheme = endpoint.scheme,
-          authority = endpoint.authority,
+          protocol: endpoint.protocol,
+          scheme: endpoint.scheme,
+          authority: endpoint.authority,
           **options
         )
           webmock_endpoint = WebMockEndpoint.new(scheme, authority, protocol)
@@ -45,6 +45,7 @@ if defined?(Async::HTTP)
           @network_client = WebMockClient.new(endpoint, **options)
           @webmock_client = WebMockClient.new(webmock_endpoint, **options)
 
+          @endpoint = endpoint
           @scheme = scheme
           @authority = authority
         end
@@ -210,7 +211,7 @@ if defined?(Async::HTTP)
           def build_response(webmock_response)
             headers = (webmock_response.headers || {}).each_with_object([]) do |(k, value), o|
               Array(value).each do |v|
-                o.push [k, v]
+                o.push [k, v] unless k.downcase == 'content-length' # async-http appends the exact content-length automatically
               end
             end
 
