@@ -8,10 +8,6 @@ unless RUBY_PLATFORM =~ /java/
   describe "EM::HttpRequest" do
     include EMHttpRequestSpecHelper
 
-    before(:all) do
-      skip 'em-http-request is not supported on Ruby >= 3.4' if Gem::Version.new(RUBY_VERSION) >= Gem::Version.new('3.4.0')
-    end
-
     include_context "with WebMock", :no_status_message
 
     #functionality only supported for em-http-request 1.x
@@ -25,7 +21,7 @@ unless RUBY_PLATFORM =~ /java/
 
         def make_request
           EM.run do
-            request = EM::HttpRequest.new(http_url, ssl: {verify_peer: true}).get(redirects: 1)
+            request = EM::HttpRequest.new(http_url, ssl: {verify_peer: false}).get(redirects: 1)
             request.callback { EM.stop }
           end
         end
