@@ -62,9 +62,9 @@ shared_context "declared responses" do |*adapter_info|
     end
 
     it "should return response with declared headers" do
-      stub_request(:get, "www.example.com").to_return(headers: SAMPLE_HEADERS)
+      stub_request(:get, "www.example.com").to_return(headers: SAMPLE_RESPONSE_HEADERS)
       response = http_request(:get, "http://www.example.com/")
-      expect(response.headers["Accept"]).to eq("application/json")
+      expect(response.headers["Content-Type"]).to eq("application/json")
       unless adapter_info.include?(:no_content_length_header)
         expect(response.headers["Content-Length"]).to eq("8888")
       end
@@ -136,6 +136,25 @@ shared_context "declared responses" do |*adapter_info|
       end
     end
 
+    describe "when response was declared via to_return_json" do
+      describe "and declared response body is lamba" do
+        it "should evaluate the response body at the time of returning the response" do
+          record = double("SomeRecord")
+          allow(record).to receive_messages(to_json: '{"what":"something callable"}.')
+
+          stub_request(:get, "www.example.com").to_return_json(body: -> {record})
+
+          allow(record).to receive_messages(to_json: '{"what":"something else callable"}.')
+          expect(http_request(:get, "http://www.example.com/").body).to eq('{"what":"something else callable"}.')
+        end
+
+        it "should evaluate the response body with request passed as argument to lambda" do
+          stub_request(:get, "www.example.com").to_return_json(body: ->(request) {"\"#{request.uri.to_s}\""})
+          expect(http_request(:get, "http://www.example.com/").body).to eq("\"http://www.example.com:80/\"")
+        end
+      end
+    end
+
     describe "when response was declared as lambda" do
       it "should return evaluated response body" do
         stub_request(:post, "www.example.com").to_return(lambda {|request|
