@@ -1,5 +1,3 @@
-# encoding: utf-8
-
 shared_examples_for "stubbing requests" do |*adapter_info|
   describe "when requests are stubbed" do
     describe "based on uri" do
@@ -368,10 +366,10 @@ shared_examples_for "stubbing requests" do |*adapter_info|
 
     describe "based on headers" do
       it "should match requests if headers are the same" do
-        stub_request(:get, "www.example.com").with(headers: SAMPLE_HEADERS )
+        stub_request(:get, "www.example.com").with(headers: SAMPLE_REQUEST_HEADERS )
         expect(http_request(
           :get, "http://www.example.com/",
-        headers: SAMPLE_HEADERS).status).to eq("200")
+        headers: SAMPLE_REQUEST_HEADERS).status).to eq("200")
       end
 
       it "should match requests if headers are the same and declared as array" do
@@ -411,16 +409,16 @@ shared_examples_for "stubbing requests" do |*adapter_info|
         stub_request(:get, "www.example.com")
         expect(http_request(
           :get, "http://www.example.com/",
-        headers: SAMPLE_HEADERS).status).to eq("200")
+        headers: SAMPLE_REQUEST_HEADERS).status).to eq("200")
       end
 
       it "should not match requests if headers are different" do
-        stub_request(:get, "www.example.com").with(headers: SAMPLE_HEADERS)
+        stub_request(:get, "www.example.com").with(headers: { "Accept" => "application/json" })
 
         expect {
           http_request(
             :get, "http://www.example.com/",
-          headers: { 'Content-Length' => '9999'})
+          headers: { "Accept" => "text/html" })
         }.to raise_error(WebMock::NetConnectNotAllowedError, %r(Real HTTP connections are disabled. Unregistered request: GET http://www.example.com/ with headers))
       end
 
