@@ -2,6 +2,7 @@ require 'rubygems'
 require 'httpclient'
 unless RUBY_PLATFORM =~ /java/
   require 'curb'
+  require 'em-http'
   require 'patron'
   require 'typhoeus'
 end
@@ -25,6 +26,8 @@ Warning[:deprecated] = true if Warning.respond_to?(:[]=)
 
 CURL_EXAMPLE_OUTPUT_PATH = File.expand_path('../support/example_curl_output.txt', __FILE__)
 
+HTTP_STATUS_SERVICE = ENV.fetch("HTTP_STATUS_SERVICE", "https://httpstat.us")
+
 RSpec.configure do |config|
   no_network_connection = ENV["NO_CONNECTION"] || ! NetworkConnection.is_network_available?
   if no_network_connection
@@ -47,4 +50,3 @@ RSpec.configure do |config|
 
   config.include Failures
 end
-
